@@ -1,6 +1,6 @@
 package Net::Twitter::Role::RateLimit;
 {
-  $Net::Twitter::Role::RateLimit::VERSION = '4.00006';
+  $Net::Twitter::Role::RateLimit::VERSION = '4.00007';
 }
 use Moose::Role;
 use namespace::autoclean;
@@ -13,13 +13,13 @@ Net::Twitter::Role::RateLimit - Rate limit features for Net::Twitter
 
 =head1 VERSION
 
-version 4.00006
+version 4.00007
 
 =head1 SYNOPSIS
 
     use Net::Twitter;
     my $nt = Net::Twitter->new(
-        traits => [qw/API::RESTv1_1 RateLimit/],
+        traits => [qw/API::REST RateLimit/],
         %other_options,
     );
 
@@ -27,6 +27,12 @@ version 4.00006
 
     sleep $nt->until_rate(1.0) || $minimum_wait;
 
+=head1 NOTE!
+
+RateLimit only works with Twitter API v1. The rate limiting strategy of Twitter
+API v1.1 is very different. A v1.1 compatible RateLimit role may be coming, but
+isn't available, yet. It's interface will necessarily be different.
+
 =head1 DESCRIPTION
 
 This provides utility methods that return information about the current
